@@ -9,8 +9,17 @@ from xml2rfc.writers.expanded_xml import ExpandedXmlWriter
 from xml2rfc.writers.v2v3 import V2v3XmlWriter
 from xml2rfc.writers.preptool import PrepToolWriter
 from xml2rfc.writers.text import TextWriter
+from xml2rfc.writers.html import HtmlWriter
+from xml2rfc.writers.expand import ExpandV3XmlWriter
+from xml2rfc.writers.pdf import PdfWriter
+from xml2rfc.writers.unprep import UnPrepWriter
+from xml2rfc.writers.doc import DocWriter
+from xml2rfc.writers.bib import DatatrackerToBibConverter
 
-# This defines what 'from xml2rfc.riters import *' actually imports:
+# This defines what 'from xml2rfc.writers import *' actually imports:
 __all__ = ['BaseRfcWriter', 'RawTextRfcWriter', 'PaginatedTextRfcWriter',
            'HtmlRfcWriter', 'NroffRfcWriter', 'ExpandedXmlWriter',
-           'RfcWriterError', 'V2v3XmlWriter', 'PrepToolWriter', 'TextWriter', ]
+           'RfcWriterError', 'V2v3XmlWriter', 'PrepToolWriter', 'TextWriter',
+           'HtmlWriter', 'PdfWriter', 'ExpandV3XmlWriter', 'UnPrepWriter', 
+           'DocWriter', 'DatatrackerToBibConverter',
+       ]
